Python access to groundwater data in South Australia
====================================================

sa_gwdata is a Python package to ease access to groundwater data in South Australia.
This is an unofficial project, use at your own risk/reward.

`The project's homepage is at GitHub <https://github.com/kinverarity1/python-sa-gwdata>`__.

.. toctree::
    :maxdepth: 6
    :caption: Contents:

    quickstart-guide
    background
    available-data
    tutorial-finding-wells
    tutorial-monitoring-networks
    tutorial-water-monitoring-data
    apidocs
    webservices
    changelog


* :ref:`genindex`
* :ref:`search`
